.. SPDX-FileCopyrightText: 2021 geisserml <geisserml@gmail.com>
.. SPDX-License-Identifier: CC-BY-4.0

Support API
===========

Version
*******
.. automodule:: pypdfium2._version

Opener/Closer
*************
.. automodule:: pypdfium2._helpers.opener
.. automodule:: pypdfium2._helpers.nativeopener

Saver
*****
.. automodule:: pypdfium2._helpers.saver

Page Renderer
*************
.. automodule:: pypdfium2._helpers.page_renderer

Document Renderer
*****************
.. automodule:: pypdfium2._helpers.pdf_renderer

TOC Parser
**********
.. automodule:: pypdfium2._helpers.toc

PDF Boxes
*********
.. automodule:: pypdfium2._helpers.boxes

Utilities
*********
.. automodule:: pypdfium2._helpers.utilities

Constants
*********
.. automodule:: pypdfium2._helpers.constants

Error Handler
*************
.. automodule:: pypdfium2._helpers.error_handler
